unit AJB_DS;

interface

uses Windows, Db, Classes;

type
  // Specialized TDataset descendant for our "table" data:
  TAJBBaseDataSet = class(TDataSet)
  private
    FFilter: string;
  protected
    { Mandatory overrides }
    // Record buffer methods:
    function AllocRecordBuffer: PChar; override;
    procedure FreeRecordBuffer(var Buffer: PChar); override;
    procedure InternalInitRecord(Buffer: PChar); override;
    function GetRecord(Buffer: PChar; GetMode: TGetMode;
      DoCheck: Boolean): TGetResult; override;
    function GetRecordSize: Word; override;
    procedure SetFieldData(Field: TField; Buffer: Pointer); override;
    // Bookmark methods:
    procedure GetBookmarkData(Buffer: PChar; Data: Pointer); override;
    function GetBookmarkFlag(Buffer: PChar): TBookmarkFlag; override;
    procedure InternalGotoBookmark(Bookmark: Pointer); override;
    procedure InternalSetToRecord(Buffer: PChar); override;
    procedure SetBookmarkFlag(Buffer: PChar; Value: TBookmarkFlag); override;
    procedure SetBookmarkData(Buffer: PChar; Data: Pointer); override;
    // Navigational methods:
    procedure InternalFirst; override;
    procedure InternalLast; override;
    // Editing methods:
    procedure InternalAddRecord(Buffer: Pointer; Append: Boolean); override;
    procedure InternalDelete; override;
    procedure InternalPost; override;
    // Misc methods:
    procedure InternalClose; override;
    procedure InternalHandleException; override;
    procedure InternalInitFieldDefs; override;
    procedure InternalOpen; override;
    function IsCursorOpen: Boolean; override;
    procedure SetFiltertext(const Value:String); override;

  public
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
    property Filter: string read FFilter write FFilter;
  end;

implementation

uses Forms;

constructor TAJBBaseDataSet.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
end;

destructor TAJBBaseDataSet.Destroy;
begin
  inherited Destroy;
end;

function TAJBBaseDataSet.AllocRecordBuffer: PChar;
begin
  Result := nil;
end;

procedure TAJBBaseDataSet.FreeRecordBuffer(var Buffer: PChar);
begin
end;

procedure TAJBBaseDataSet.InternalInitRecord(Buffer: PChar);
begin
end;

function TAJBBaseDataSet.GetRecord(Buffer: PChar; GetMode: TGetMode; DoCheck: 
    Boolean): TGetResult;
begin
    Result := grEOF;
end;

function TAJBBaseDataSet.GetRecordSize: Word;
begin
  Result := 0;
end;

procedure TAJBBaseDataSet.SetFieldData(Field: TField; Buffer: Pointer);
begin
end;

procedure TAJBBaseDataSet.GetBookmarkData(Buffer: PChar; Data: Pointer);
begin
end;

function TAJBBaseDataSet.GetBookmarkFlag(Buffer: PChar): TBookmarkFlag;
begin
  Result := bfBOF;
end;

procedure TAJBBaseDataSet.InternalGotoBookmark(Bookmark: Pointer);
begin
end;

procedure TAJBBaseDataSet.InternalSetToRecord(Buffer: PChar);
begin
end;

procedure TAJBBaseDataSet.SetBookmarkData(Buffer: PChar; Data: Pointer);
begin
end;

procedure TAJBBaseDataSet.SetBookmarkFlag(Buffer: PChar; Value: TBookmarkFlag);
begin
end;

procedure TAJBBaseDataSet.InternalFirst;
begin
end;

procedure TAJBBaseDataSet.InternalInitFieldDefs;
begin
  // create FieldDefs which map to each field in the data record
  FieldDefs.Clear;
  InitFielddefsFromFields;
end;

procedure TAJBBaseDataSet.InternalLast;
begin
end;

procedure TAJBBaseDataSet.InternalClose;
begin
  if DefaultFields then
    DestroyFields;
end;

procedure TAJBBaseDataSet.InternalHandleException;
begin
  // standard implementation for this method:
  Application.HandleException(Self);
end;

procedure TAJBBaseDataSet.InternalDelete;
begin
end;

procedure TAJBBaseDataSet.InternalAddRecord(Buffer: Pointer; Append: Boolean);
begin
end;

procedure TAJBBaseDataSet.InternalOpen;
begin
    BookmarkSize := SizeOf(Integer);   // initialize bookmark size for VCL
    InternalInitFieldDefs;             // initialize FieldDef objects
    // Create TField components when no persistent fields have been created
    if DefaultFields then CreateFields;
    BindFields(True);                  // bind FieldDefs to actual data
end;

procedure TAJBBaseDataSet.InternalPost;
begin
end;

function TAJBBaseDataSet.IsCursorOpen: Boolean;
begin
  Result := True;
end;

procedure TAJBBaseDataSet.SetFiltertext(const Value:String);
begin
  FFilter:=Value; //needed for correct setting of ancestor
end;


end.
